# REHO
Renewable Energy Hub Optimizer (REHO) is a decision support tool for sustainable urban energy system planning.
REHO simultaneously addresses the optimal design and operation of capacities, catering to multi-objective considerations
across economic, environmental, and efficiency criteria.

Key features:
* MILP Framework
* Multi-Objective Optimization
* Multi-Scale Capabilities
* Multi-Service Consideration
* Multi-Energy Integration
* Open-Source and Open-Data

For more information about the model foundations and features, please refer to the [REHO documentation](https://reho.readthedocs.io/en/main/).

## Authors
REHO is developed by EPFL (Switzerland), within the Industrial Process and Energy Systems Engineering (IPESE) group.

Dorsan Lepour <dorsan.lepour@epfl.ch>  
Cédric Terrier <cedric.terrier@epfl.ch>  
Joseph Loustau

## Licence
Copyright (C) <2021-2024> <Ecole Polytechnique Fédérale de Lausanne (EPFL), Switzerland>

Licensed under the Apache License, (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Description and complete License: see LICENSE file.

## Installation

REHO is available as a [PyPI package](https://pypi.org/project/REHO/) and can be installed via pip with:
```
pip install --extra-index-url https://pypi.ampl.com REHO
```

Full code can be accessed from the [REHO GitHub repository](https://github.com/IPESE/REHO) and cloned with:
```
git clone https://github.com/IPESE/REHO.git
```

Please refer to "[Getting started](https://reho.readthedocs.io/en/main/sections/5_Getting_started.html)" section of the documentation for step-by-step guidelines.

## Suggestions and contributions
All suggestions or implementation must be tracked with dedicated issues and reported in the project repository.

Refer to "[Contribute](https://reho.readthedocs.io/en/main/sections/7_Contribute.html)" section of the documentation for further guidance.

